@@ -28,4 +28,4 @@ bumpver("pysrc/juliacall/juliapkg.json", "\"version\": \"={}\"", oldver, newver)
 bumpver("pysrc/juliacall/juliapkg-dev.json", "\"version\": \"={}\"", oldver, newver)
 bumpver("src/API/API.jl", "VERSION = v\"{}\"", oldver, newver)
 bumpver("src/Core/Core.jl", "VERSION = v\"{}\"", oldver, newver)
-bump("docs/src/releasenotes.md", "## Unreleased", "## $newver ($(today()))")
+bump("CHANGELOG.md", "## Unreleased", "## $newver ($(today()))")
